@@ -731,6 +731,18 @@ static grn_logger_info default_logger = {
 
 static const grn_logger_info *grn_logger = &default_logger;
 
+void
+grn_default_logger_set_max_level(grn_log_level level)
+{
+  default_logger.max_level = level;
+}
+
+grn_log_level
+grn_default_logger_get_max_level(void)
+{
+  return default_logger.max_level;
+}
+
 void
 grn_log_reopen(grn_ctx *ctx)
 {
@@ -776,16 +788,18 @@ check_overcommit_memory(grn_ctx *ctx)
   value = fgetc(file);
   if (value != '1') {
     GRN_LOG(ctx, GRN_LOG_NOTICE,
-            "vm.overcommit_memory kernel parameter should be 1: <%c>", value);
-    GRN_LOG(ctx, GRN_LOG_NOTICE,
+            "vm.overcommit_memory kernel parameter should be 1: <%c>: "
+            "See INFO level log to resolve this",
+            value);
+    GRN_LOG(ctx, GRN_LOG_INFO,
             "Some processings with vm.overcommit_memory != 1 "
             "may break DB under low memory condition.");
-    GRN_LOG(ctx, GRN_LOG_NOTICE,
+    GRN_LOG(ctx, GRN_LOG_INFO,
             "To set vm.overcommit_memory to 1");
-    GRN_LOG(ctx, GRN_LOG_NOTICE,
+    GRN_LOG(ctx, GRN_LOG_INFO,
             "add 'vm.overcommit_memory = 1' to /etc/sysctl.conf and "
             "restart your system or");
-    GRN_LOG(ctx, GRN_LOG_NOTICE,
+    GRN_LOG(ctx, GRN_LOG_INFO,
             "run 'sudo /sbin/sysctl vm.overcommit_memory=1' command.");
   }
   fclose(file);
@@ -1079,6 +1093,9 @@ grn_get_ctype(grn_obj *var)
 static void
 get_content_mime_type(grn_ctx *ctx, const char *p, const char *pe)
 {
+  ctx->impl->output_type = GRN_CONTENT_NONE;
+  ctx->impl->mime_type = "application/octet-stream";
+
   if (p + 2 <= pe) {
     switch (*p) {
     case 'c' :
