@@ -410,14 +410,15 @@ extern grn_timeval grn_starttime;
   grn_timeval_now(ctx, &tv);\
   et = (uint64_t)(tv.tv_sec - ctx->impl->tv.tv_sec) * GRN_TIME_NSEC_PER_SEC\
     + (tv.tv_nsec - ctx->impl->tv.tv_nsec);\
-  GRN_LOG(ctx, GRN_LOG_NONE, "%08x|" prefix "%015llu " format, (intptr_t)ctx, et, __VA_ARGS__);\
+  GRN_LOG(ctx, GRN_LOG_NONE, "%p|" prefix "%015" GRN_FMT_INT64U " " format,\
+          ctx, et, __VA_ARGS__);\
 } while (0)
 
 GRN_API grn_rc grn_timeval_now(grn_ctx *ctx, grn_timeval *tv);
 GRN_API grn_rc grn_timeval2str(grn_ctx *ctx, grn_timeval *tv, char *buf);
 grn_rc grn_str2timeval(const char *str, uint32_t str_len, grn_timeval *tv);
 
-GRN_API void grn_ctx_log(grn_ctx *ctx, const char *fmt, ...);
+GRN_API void grn_ctx_log(grn_ctx *ctx, const char *fmt, ...) GRN_ATTRIBUTE_PRINTF(2);
 void grn_ctx_qe_fin(grn_ctx *ctx);
 void grn_ctx_loader_clear(grn_ctx *ctx);
 void grn_log_reopen(grn_ctx *ctx);
@@ -494,9 +495,6 @@ void grn_cache_get_statistics(grn_ctx *ctx, grn_cache_statistics *statistics);
 
 /**** receive handler ****/
 
-GRN_API void grn_ctx_recv_handler_set(grn_ctx *c, void (*func)(grn_ctx *, int, void *),
-                                      void *func_arg);
-
 void grn_ctx_concat_func(grn_ctx *ctx, int flags, void *dummy);
 GRN_API void grn_ctx_stream_out_func(grn_ctx *c, int flags, void *stream);
 
