@@ -1993,6 +1993,9 @@ show_usage(FILE *output)
           "                           (default: %s)\n"
           "\n"
           "Common options:\n"
+          "      --working-directory <path>:\n"
+          "                       specify working directory path\n"
+          "                       (none)\n"
           "      --config-path <path>:\n"
           "                       specify config file path\n"
           "                       (default: %s)\n"
@@ -2029,7 +2032,8 @@ main(int argc, char **argv)
     *cache_limit_arg = NULL, *document_root_arg = NULL,
     *default_command_version_arg = NULL,
     *default_match_escalation_threshold_arg = NULL,
-    *input_fd_arg = NULL, *output_fd_arg = NULL;
+    *input_fd_arg = NULL, *output_fd_arg = NULL,
+    *working_directory_arg = NULL;
   const char *config_path = NULL;
   int exit_code = EXIT_SUCCESS;
   int i, mode = mode_alone;
@@ -2060,6 +2064,7 @@ main(int argc, char **argv)
     {'\0', "bind-address", NULL, 0, getopt_op_none},
     {'\0', "input-fd", NULL, 0, getopt_op_none},
     {'\0', "output-fd", NULL, 0, getopt_op_none},
+    {'\0', "working-directory", NULL, 0, getopt_op_none},
     {'\0', NULL, NULL, 0, 0}
   };
   opts[0].arg = &port_arg;
@@ -2080,6 +2085,7 @@ main(int argc, char **argv)
   opts[23].arg = &bind_address_arg;
   opts[24].arg = &input_fd_arg;
   opts[25].arg = &output_fd_arg;
+  opts[26].arg = &working_directory_arg;
 
   init_default_settings();
 
@@ -2112,6 +2118,15 @@ main(int argc, char **argv)
       return EXIT_FAILURE;
     }
   }
+
+  if (working_directory_arg) {
+    if (chdir(working_directory_arg) == -1) {
+      fprintf(stderr, "%s: failed to change directory: %s: %s\n",
+              argv[0], working_directory_arg, strerror(errno));
+      return EXIT_FAILURE;
+    }
+  }
+
   /* ignore mode option in config file */
   mode = (mode == mode_error) ? default_mode :
     ((mode & ~MODE_MASK) | default_mode);
@@ -2219,6 +2234,20 @@ main(int argc, char **argv)
     grn_qlog_path = query_log_path_arg;
   }
 
+  if (log_level_arg) {
+    const char * const end = log_level_arg + strlen(log_level_arg);
+    const char *rest = NULL;
+    const int value = grn_atoi(log_level_arg, end, &rest);
+    if (end != rest || value < 0 || value > 9) {
+      fprintf(stderr, "invalid log level: <%s>\n", log_level_arg);
+      return EXIT_FAILURE;
+    }
+    log_level = value;
+  } else {
+    log_level = default_log_level;
+  }
+  grn_default_logger_set_max_level(log_level);
+
   if (max_num_threads_arg) {
     const char * const end = max_num_threads_arg + strlen(max_num_threads_arg);
     const char *rest = NULL;
@@ -2353,19 +2382,6 @@ main(int argc, char **argv)
     default_match_escalation_threshold = default_default_match_escalation_threshold;
   }
 
-  if (log_level_arg) {
-    const char * const end = log_level_arg + strlen(log_level_arg);
-    const char *rest = NULL;
-    const int value = grn_atoi(log_level_arg, end, &rest);
-    if (end != rest || value < 0 || value > 9) {
-      fprintf(stderr, "invalid log level: <%s>\n", log_level_arg);
-      return EXIT_FAILURE;
-    }
-    log_level = value;
-  } else {
-    log_level = default_log_level;
-  }
-
   if (cache_limit_arg) {
     const char * const end = cache_limit_arg + strlen(cache_limit_arg);
     const char *rest = NULL;
