@@ -32,7 +32,6 @@ void test_time_float(void);
 void data_null(void);
 void test_null(gconstpointer data);
 void test_index_geo_point(void);
-void test_nonexistent_columns(void);
 void test_no_key_table(void);
 void test_two_bigram_indexes_to_key(void);
 void test_invalid_start_with_symbol(void);
@@ -42,11 +41,7 @@ void test_invalid_table_name(void);
 void data_each(void);
 void test_each(gconstpointer data);
 void test_vector_reference_column(void);
-void test_invalid_int32_value(void);
-void data_valid_geo_point_valid(void);
-void test_valid_geo_point_value(gconstpointer data);
-void data_invalid_geo_point_valid(void);
-void test_invalid_geo_point_value(gconstpointer data);
+void test_vector_domain(void);
 
 static gchar *tmp_directory;
 static const gchar *database_path;
@@ -313,66 +308,6 @@ test_null(gconstpointer data)
                           send_command("select Students"));
 }
 
-void
-test_index_geo_point(void)
-{
-  const gchar *query =
-    "select Shops "
-    "--filter 'geo_in_circle(location, \"128514964x502419287\", 1)'";
-  const gchar *hit_result =
-    "[[[1],"
-    "[[\"_id\",\"UInt32\"],"
-    "[\"_key\",\"ShortText\"],"
-    "[\"location\",\"WGS84GeoPoint\"]],"
-    "[1,\"たかね\",\"128514964x502419287\"]]]";
-  const gchar *no_hit_result =
-    "[[[0],"
-    "[[\"_id\",\"UInt32\"],"
-    "[\"_key\",\"ShortText\"],"
-    "[\"location\",\"WGS84GeoPoint\"]]]]";
-  const gchar *load_takane =
-    "load --table Shops\n"
-    "[{\"_key\": \"たかね\", \"location\": \"128514964x502419287\"}]";
-  const gchar *load_takane_with_empty_location =
-    "load --table Shops\n"
-    "[{\"_key\": \"たかね\", \"location\": null}]";
-
-  assert_send_command("table_create Shops TABLE_HASH_KEY ShortText");
-  assert_send_command("column_create Shops location COLUMN_SCALAR WGS84GeoPoint");
-  assert_send_command("table_create Locations TABLE_PAT_KEY WGS84GeoPoint");
-  assert_send_command("column_create Locations shop COLUMN_INDEX Shops location");
-
-  cut_assert_equal_string("1",
-                          send_command(load_takane));
-  cut_assert_equal_string(hit_result,
-                          send_command(query));
-
-  cut_assert_equal_string("1",
-                          send_command(load_takane_with_empty_location));
-  cut_assert_equal_string(no_hit_result,
-                          send_command(query));
-
-  cut_assert_equal_string("1",
-                          send_command(load_takane));
-  cut_assert_equal_string(hit_result,
-                          send_command(query));
-}
-
-void
-test_nonexistent_columns(void)
-{
-  assert_send_command("table_create Users TABLE_NO_KEY");
-  assert_send_command("column_create Users name COLUMN_SCALAR ShortText");
-  grn_test_assert_send_command_error(context,
-                                     GRN_INVALID_ARGUMENT,
-                                     "nonexistent column: <nonexistent>",
-                                     "load "
-                                     "--table Users "
-                                     "--columns nonexistent "
-                                     "--values "
-                                     "'[[\"nonexistent column value\"]]'");
-}
-
 void
 test_no_key_table(void)
 {
@@ -503,65 +438,6 @@ test_invalid_table_name(void)
     "]");
 }
 
-void
-data_each(void)
-{
-#define ADD_DATUM(label, load_values_format)                            \
-  gcut_add_datum(label,                                                 \
-                 "load-values-format", G_TYPE_STRING, load_values_format, \
-                 NULL)
-
-  ADD_DATUM("brace",
-            "{\"_key\": \"alice\", \"location\": \"%s\"},"
-            "{\"_key\": \"bob\", \"location\": \"%s\"}");
-
-  ADD_DATUM("bracket",
-            "[\"_key\", \"location\"],"
-            "[\"alice\", \"%s\"],"
-            "[\"bob\", \"%s\"]");
-
-#undef ADD_DATUM
-}
-
-void
-test_each(gconstpointer data)
-{
-  gdouble tokyo_tocho_latitude = 35.689444;
-  gdouble tokyo_tocho_longitude = 139.691667;
-  gdouble yurakucho_latitude = 35.67487;
-  gdouble yurakucho_longitude = 139.76352;
-  gdouble asagaya_latitude = 35.70452;
-  gdouble asagaya_longitude = 139.6351;
-
-  assert_send_command("table_create Users TABLE_HASH_KEY ShortText");
-  assert_send_command("column_create Users location "
-                      "COLUMN_SCALAR WGS84GeoPoint");
-  assert_send_command("column_create Users distance_from_tokyo_tocho "
-                      "COLUMN_SCALAR UInt32");
-  cut_assert_equal_string(
-    "2",
-    send_command(
-      cut_take_printf(
-        "load "
-        "--table Users "
-        "--each 'distance_from_tokyo_tocho = geo_distance(location, \"%s\")' "
-        "--values '[%s]'",
-        grn_test_location_string(tokyo_tocho_latitude, tokyo_tocho_longitude),
-        cut_take_printf(gcut_data_get_string(data, "load-values-format"),
-                        grn_test_location_string(yurakucho_latitude,
-                                                 yurakucho_longitude),
-                        grn_test_location_string(asagaya_latitude,
-                                                 asagaya_longitude)))));
-  cut_assert_equal_string(
-    "[[[2],"
-     "[[\"_id\",\"UInt32\"],"
-      "[\"_key\",\"ShortText\"],"
-      "[\"distance_from_tokyo_tocho\",\"UInt32\"],"
-      "[\"location\",\"WGS84GeoPoint\"]],"
-     "[1,\"alice\",6674,\"128429532x503148672\"],"
-     "[2,\"bob\",5364,\"128536272x502686360\"]]]",
-    send_command("select Users"));
-}
 
 void
 test_vector_reference_column(void)
@@ -586,104 +462,31 @@ test_vector_reference_column(void)
 }
 
 void
-test_invalid_int32_value(void)
+test_vector_domain(void)
 {
-  assert_send_command("table_create Users TABLE_NO_KEY");
-  assert_send_command("column_create Users age COLUMN_SCALAR Int32");
-  grn_test_assert_send_command_error(
-    context,
-    GRN_INVALID_ARGUMENT,
-    "<Users.age>: failed to cast to <Int32>: <\"invalid number!\">",
-    "load --table Users\n"
-    "[\n"
-    "{\"age\": \"invalid number!\"}\n"
-    "]\n");
-  send_command("]\n");
-  cut_assert_equal_string(
-    "[[[1],"
-     "[[\"_id\",\"UInt32\"],"
-      "[\"age\",\"Int32\"]],"
-     "[1,0]]]",
-    send_command("select Users"));
-}
-
-void
-data_valid_geo_point_value(void)
-{
-#define ADD_DATUM(label, location)                                      \
-  gcut_add_datum(label " (" location ")",                               \
-                 "location", G_TYPE_STRING, location,                   \
-                 NULL)
-
-  ADD_DATUM("too large latitude", "324000000x502419287");
-  ADD_DATUM("too small latitude", "-324000000x502419287");
-  ADD_DATUM("too large longitude", "128514964x648000000");
-  ADD_DATUM("too small longitude", "128514964x-648000000");
-
-#undef ADD_DATUM
-}
-
-void
-test_valid_geo_point_value(gconstpointer data)
-{
-  assert_send_command("table_create Shops TABLE_HASH_KEY ShortText");
-  assert_send_command("column_create Shops location COLUMN_SCALAR WGS84GeoPoint");
+  assert_send_command("table_create Posts TABLE_NO_KEY");
+  assert_send_command("column_create Posts tags COLUMN_VECTOR ShortText");
   cut_assert_equal_string(
     "1",
     send_command(
-      cut_take_printf("load --table Shops\n"
-                      "[\n"
-                      "{\"_key\": \"たかね\", \"location\": \"%s\"}\n"
-                      "]\n",
-                      gcut_data_get_string(data, "location"))));
-  cut_assert_equal_string(
-    cut_take_printf("[[[1],"
-                    "[[\"_id\",\"UInt32\"],"
-                    "[\"_key\",\"ShortText\"],"
-                    "[\"location\",\"WGS84GeoPoint\"]],"
-                    "[1,\"たかね\",\"%s\"]]]",
-                    gcut_data_get_string(data, "location")),
-    send_command("select Shops"));
-}
+      "load "
+      "--table Posts "
+      "--values '[{\"tags\": [\"groonga\", \"search engine\"]}]'"));
 
-void
-data_invalid_geo_point_value(void)
-{
-#define ADD_DATUM(label, location)                                      \
-  gcut_add_datum(label " (" location ")",                               \
-                 "location", G_TYPE_STRING, location,                   \
-                 NULL)
+  {
+    grn_obj *tags_column;
+    grn_obj tags;
+    const char *tag;
+    grn_id domain;
 
-  ADD_DATUM("too large latitude", "324000001x502419287");
-  ADD_DATUM("too small latitude", "-324000001x502419287");
-  ADD_DATUM("too large longitude", "128514964x648000001");
-  ADD_DATUM("too small longitude", "128514964x-648000001");
+    tags_column = grn_ctx_get(context, "Posts.tags", strlen("Posts.tags"));
+    GRN_SHORT_TEXT_INIT(&tags, GRN_OBJ_VECTOR);
+    grn_obj_get_value(context, tags_column, 1, &tags);
+    cut_assert_equal_int(2, grn_vector_size(context, &tags));
+    grn_vector_get_element(context, &tags, 0, &tag, NULL, &domain);
+    GRN_OBJ_FIN(context, &tags);
+    grn_obj_unlink(context, tags_column);
 
-#undef ADD_DATUM
-}
-
-void
-test_invalid_geo_point_value(gconstpointer data)
-{
-  assert_send_command("table_create Shops TABLE_HASH_KEY ShortText");
-  assert_send_command("column_create Shops location COLUMN_SCALAR WGS84GeoPoint");
-  grn_test_assert_send_command_error(
-    context,
-    GRN_INVALID_ARGUMENT,
-    cut_take_printf("<Shops.location>: "
-                    "failed to cast to <WGS84GeoPoint>: <\"%s\">",
-                    gcut_data_get_string(data, "location")),
-    cut_take_printf("load --table Shops\n"
-                    "[\n"
-                    "{\"_key\": \"たかね\", \"location\": \"%s\"}\n"
-                    "]\n",
-                    gcut_data_get_string(data, "location")));
-  send_command("]\n");
-  cut_assert_equal_string(
-    "[[[1],"
-     "[[\"_id\",\"UInt32\"],"
-      "[\"_key\",\"ShortText\"],"
-      "[\"location\",\"WGS84GeoPoint\"]],"
-     "[1,\"たかね\",\"0x0\"]]]",
-    send_command("select Shops"));
+    grn_test_assert_equal_id(context, GRN_DB_SHORT_TEXT, domain);
+  }
 }
