@@ -90,6 +90,51 @@ load --table Entry
 ["_key","body"],
 ["gcc","#{body}"]
 ]
+load --table Terms
+[
+["_key"],
+["、"],
+["。"],
+["して"],
+["しま"],
+["す"],
+["する"],
+["て使"],
+["とし"],
+["ます"],
+["るテ"],
+["るト"],
+["る場"],
+["を分"],
+["を指"],
+["を語"],
+["イザ"],
+["クナ"],
+["ザを"],
+["テー"],
+["トー"],
+["ナイ"],
+["ブル"],
+["ルを"],
+["ーク"],
+["ーブ"],
+["作成"],
+["使用"],
+["分割"],
+["列を"],
+["割す"],
+["合"],
+["場合"],
+["字列"],
+["定し"],
+["彙表"],
+["成す"],
+["指定"],
+["文字"],
+["用す"],
+["表と"],
+["語彙"]
+]
 EOC
   end
 
@@ -142,6 +187,51 @@ table_create Terms TABLE_PAT_KEY|KEY_NORMALIZE ShortText --default_tokenizer Tok
 table_create Entry TABLE_HASH_KEY ShortText
 column_create Entry body COLUMN_SCALAR ShortText
 column_create Terms entry_body COLUMN_INDEX Entry body
+load --table Terms
+[
+["_key"],
+["、"],
+["。"],
+["して"],
+["しま"],
+["す"],
+["する"],
+["て使"],
+["とし"],
+["ます"],
+["るテ"],
+["るト"],
+["る場"],
+["を分"],
+["を指"],
+["を語"],
+["イザ"],
+["クナ"],
+["ザを"],
+["テー"],
+["トー"],
+["ナイ"],
+["ブル"],
+["ルを"],
+["ーク"],
+["ーブ"],
+["作成"],
+["使用"],
+["分割"],
+["列を"],
+["割す"],
+["合"],
+["場合"],
+["字列"],
+["定し"],
+["彙表"],
+["成す"],
+["指定"],
+["文字"],
+["用す"],
+["表と"],
+["語彙"]
+]
 load --table Entry
 [
 ["_key","body"],
@@ -165,6 +255,54 @@ load --table Entry
 ["_key","body","title"],
 ["gcc","#{body}","#{title}"]
 ]
+load --table Terms
+[
+["_key"],
+["_"],
+["default"],
+["tokenizer"],
+["、"],
+["。"],
+["して"],
+["しま"],
+["す"],
+["する"],
+["て使"],
+["とし"],
+["ます"],
+["るテ"],
+["るト"],
+["る場"],
+["を分"],
+["を指"],
+["を語"],
+["イザ"],
+["クナ"],
+["ザを"],
+["テー"],
+["トー"],
+["ナイ"],
+["ブル"],
+["ルを"],
+["ーク"],
+["ーブ"],
+["作成"],
+["使用"],
+["分割"],
+["列を"],
+["割す"],
+["合"],
+["場合"],
+["字列"],
+["定し"],
+["彙表"],
+["成す"],
+["指定"],
+["文字"],
+["用す"],
+["表と"],
+["語彙"]
+]
 EOC
   end
 
